--[[
    ... links and notes should be here ...
]]

local _, addonTable = ...
local config = addonTable.config

if not config.showSpellID then
    return -- ignore the code below
end

local function addLine(tooltip, id)
    if not id then return end

    local hexColor = config.spellIDColor:GenerateHexColor()

    tooltip:AddLine('|c' .. hexColor .. config.spellIDText .. '|r ' .. id, 1, 1, 1)
    tooltip:Show() -- update borders correctly
end

local function onTooltipSetSpell(self)
    local id = select(2, self:GetSpell())

    -- Fix duplicate line issue in PlayerTalentFrame (Retail)
    for i = self:NumLines(), 3, -1 do
        local lineText = _G[self:GetName() .. 'TextLeft' .. i]:GetText()

        -- If the "Spell ID" line is found
        if string.match(lineText, config.spellIDText) then
            return -- stop the loop and exit the function
        end
    end
    addLine(self, id)
end

local function setUnitAura(self, unit, index, filter)
    local id = select(10, UnitAura(unit, index, filter))

    addLine(self, id)
end

GameTooltip:HookScript('OnTooltipSetSpell', onTooltipSetSpell) -- SpellBookFrame, PlayerTalentFrame, ...
hooksecurefunc(GameTooltip, 'SetUnitAura', setUnitAura) -- BuffFrame
hooksecurefunc(GameTooltip, 'SetUnitBuff', setUnitAura) -- UnitFrame
hooksecurefunc(GameTooltip, 'SetUnitDebuff', setUnitAura) -- UnitFrame